*Jana von Stein
*STATA code for the maximum likelihood estimator used in Jana von Stein (jana.vonstein@vuw.ac.nz), 
*"Do Treaties Constrain or Screen? Selection Bias and Treaty Compliance" 

*---------------------------------------------------------------------------------------------------------------------------
*ESTIMATOR 1: this estimator will give you most of the estimates you need, but in order to get all of them, it is also 
*necessary to run estimators 2 through 4 (below)
*Any section where you need to add information (variables, etc.) appears in CAPS below. Please refer to the codebook (also 
in the zip file) for explanation.


*Begin estimator 1
capture program drop biselect
program define biselect
version 7
         args lnf theta1 theta2 theta3 zrhoS zrhoN 

	tempvar rhoN rhoS 
	qui gen double `rhoN' = (exp(2*`zrhoN')-1) / (exp(2*`zrhoN')+1) 
	qui gen double `rhoS' = (exp(2*`zrhoS')-1) / (exp(2*`zrhoS')+1)

      quietly replace `lnf' = ln(($ML_y1==1)*binorm(`theta1',$ML_y2*`theta2', $ML_y2*`rhoS')+($ML_y1==0)*binorm(-`theta1',$ML_y3*`theta3', -$ML_y3*`rhoN'))
end

set matsize 150
capture drop y1
capture drop y2
capture drop y3
capture drop y1n

gen y1=SELECTION EQUATION DEPENDENT VARIABLE NAME HERE
gen y1n=-y1
gen y2=2*OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE -1
gen y3=y2

local ivar1 "SELECTION EQUATION INDEPENDENT VARIABLES HERE -- INCLUDING, IF APPPLICABLE, (a) THROUGH (c) DESCRIBED ON PAGE 1 OF THE CODEBOOK" 
local ivar2 "OUTCOME EQUATION INDEPENDENT VARIABLES FOR SIGNATORIES HERE"
local ivar3 "OUTCOME EQUATION INDEPENDENT VARIABLES FOR NON-SIGNATORIES HERE"


prob y1 `ivar1' 
local ll1=e(ll)
qui matrix i1 = e(b)
qui matrix coleq i1 = eq1:

prob OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE `ivar2' 
local ll2=e(ll)
qui matrix i2 = e(b)
qui matrix coleq i2 = eq2:
 
prob OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE `ivar3' if y1==0
local ll3=e(ll)
qui matrix i3 = e(b)
qui matrix coleq i3 = eq3:

heckprob OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE `ivar2', select (y1 = `ivar1') 
qui matrix i4 = e(b)
qui matrix rS=i4[1,"athrho:_cons"]
qui matrix coleq rS= eq4:

heckprob OUTCOME EQUATION DEPENDENT VARIABLE HERE `ivar3', select (y1n = `ivar1')
qui matrix i5 = e(b)
qui matrix rN=-i5[1,"athrho:_cons"]
qui matrix coleq rN= eq5:

qui matrix initvec = i1,i2,i3,rS,rN

ml model lf biselect (y1 = `ivar1') (y2 = `ivar2') (y3 = `ivar3') () ()
ml init initvec, skip
ml search
ml maximize, difficult
	

*The coefficient on rhos (to be reported in tables, etc.) is:
disp (exp(2*[eq4]_cons)-1) / (exp(2*[eq4]_cons)+1)

*The coefficient on rhon (to be reported in tables, etc.) is:
disp (exp(2*[eq5]_cons)-1) / (exp(2*[eq5]_cons)+1)

*Are the constants in the two outcome equations equal?
test [eq2=eq3]:_cons

*Are the coefficients on a particular independent variable in the outcome equations equal?
test [eq2=eq3]: INDEPENDENT VARIABLE OF INTEREST HERE

est store est1

*End estimator 1

*---------------------------------------------------------------------------------------------------------------------------
*PREDICTED PROBABILITIES (Method 1)
*PLEASE see the "Predicted Probabilities" section of the codebook for a description of what this part of the file does and 
discussion of where to set mean values if you are generating hypothetical predicted probabilities. Below is method (1) as 
*described in the codebook.

*Begin method (1)
capture drop selects selnegs rests rhonegs binorms norms probs selectn selnegn restn rhonegn binormn normn probn

predict selects, eq(eq1)
gen selnegs = -1*selects

predict restn, eq(eq3)
gen rhonegn = -1*rhon
gen binormn = binorm(selnegs,restn,rhonegn)
gen normn = normprob(selnegs) 
*Predicted probabilities of outcome behavior of non-selecting "type" under non-selected regime (e.g., restriction behavior
*of non-signing "type" not under Article VIII regime).
gen probn = binormn/normn
	 
predict rests, eq(eq2)
gen rhonegs = -1*rhos
gen binorms = binorm(selnegs,rests,rhonegs)
gen norms = normprob(selnegs) 
*Predicted probabilities of what outcome behavior would be if non-selecting "type" were under selected regime (e.g., 
*restriction behavior if non-signing "type" were moved into Article VIII regime)
gen probs = binorms/norms

*End method (1)
	
*---------------------------------------------------------------------------------------------------------------------------
*PREDICTED PROBABILITIES (Method 2)
*PLEASE see the "Predicted Probabilities" section of the codebook for a description of what this part of the file does and 
discussion of where to set mean values if you are generating hypothetical predicted probabilities. Below is method (2) as 
*described in the codebook.

*Begin method (2)
capture drop selects selnegs rests rhonegs binorms norms probs selectn selnegn restn rhonegn binormn normn probn

predict selects, eq(eq1)

predict rests, eq(eq2)
gen binorms = binorm(selects,rests,rhos)
gen norms = normprob(selects) 
*Predicted probabilities of outcome behavior of selecting "type" under selected regime (e.g., restriction behavior of signing
*"type" under Article VIII regime)
gen probs = binorms/norms
	

predict restn, eq(eq3)
gen binormn = binorm(selects,restn,rhon)
gen normn = normprob(selects)
*Predicted probabilities of what outcome behavior would be if selecting "type" were under non-selected regime (e.g., 
*restriction behavior if signing "type" were not under Article VIII regime)
gen probn = binormn/normn

*End method (2)

*---------------------------------------------------------------------------------------------------------------------------
*ESTIMATOR 2: this estimator will allow you to test the null hypothesis that rho-s and rho-n are jointly insignificant.  The
*p-value associated with the chi-square value that you get at the end of the output is the p-value of the null hypothesis. Be 
*sure to run the entire file.
*Any section where you need to add information (variables, etc.) appears in CAPS below. Please refer to the codebook (also 
*in the zip file) for explanation.

*Begin estimator 2
capture program drop biselect
program define biselect
version 7
         args lnf theta1 theta2 theta3  

      quietly replace `lnf' = ln(($ML_y1==1)*binorm(`theta1',$ML_y2*`theta2', $ML_y2*0)+($ML_y1==0)*binorm(-`theta1',$ML_y3*`theta3', -$ML_y3*0))
end

set matsize 150
capture drop y1
capture drop y2
capture drop y3
capture drop y1n

gen y1=SELECTION EQUATION DEPENDENT VARIABLE NAME HERE
gen y1n=-y1
gen y2=2*OUTCOME EQUATION DEPENDENT VARIABLE HERE-1
gen y3=y2

local ivar1 "SELECTION EQUATION DEPENDENT VARIABLES HERE, INCLUDING, IF APPPLICABLE, (a) THROUGH (c) DESCRIBED ON PAGE 1 OF THE CODEBOOK" 
local ivar2 "OUTCOME EQUATION INDEPENDENT VARIABLES FOR SIGNATORIES HERE"
local ivar3 "OUTCOME EQUATION INDEPENDENT VARIABLES FOR NON-SIGNATORIES HERE"


prob y1 `ivar1' 
local ll1=e(ll)
qui matrix i1 = e(b)
qui matrix coleq i1 = eq1:

prob OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE`ivar2' if y1==1
local ll2=e(ll)
qui matrix i2 = e(b)
qui matrix coleq i2 = eq2:
 
prob OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE `ivar3' if y1==0
local ll3=e(ll)
qui matrix i3 = e(b)
qui matrix coleq i3 = eq3:

heckprob OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE `ivar2', select (y1 = `ivar1') 
qui matrix i4 = e(b)
qui matrix rS=i4[1,"athrho:_cons"]
qui matrix coleq rS= eq4:

heckprob OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE `ivar3', select (y1n = `ivar1')
qui matrix i5 = e(b)
qui matrix rN=-i5[1,"athrho:_cons"]
qui matrix coleq rN= eq5:


qui matrix initvec = i1,i2,i3

ml model lf biselect (y1 = `ivar1') (y2 = `ivar2') (y3 = `ivar3')
ml init initvec, skip
ml search
ml maximize, difficult

est store est2
*CALCULATE THE PROBABILITY THAT JOINT EFFECT OF RHO-S AND RHO-N = 0
lrtest est1 est2

*End estimator 2

*---------------------------------------------------------------------------------------------------------------------------
*ESTIMATOR 3: this estimator will allow you to test the null hypothesis that rho-s is statistically insignificant. The 
*p-value associated with the chi-square value that you get at the end of the output is the p-value associated with the 
*variable rho-s. Be sure to run the entire file.
*Any section where you need to add information (variables, etc.) appears in CAPS below. Please refer to the codebook (also 
*in the zip file) for explanation.

*Begin estimator 3
capture program drop biselect
program define biselect
version 7
         args lnf theta1 theta2 theta3 zrhoN 

	tempvar rhoN rhoS 
	qui gen double `rhoN' = (exp(2*`zrhoN')-1) / (exp(2*`zrhoN')+1) 

      quietly replace `lnf' = ln(($ML_y1==1)*binorm(`theta1',$ML_y2*`theta2', $ML_y2*0)+($ML_y1==0)*binorm(-`theta1',$ML_y3*`theta3', -$ML_y3*`rhoN'))
end

set matsize 150
capture drop y1
capture drop y2
capture drop y3
capture drop y1n

gen y1=SELECTION EQUATION DEPENDENT VARIABLE NAME HERE
gen y1n=-y1
gen y2=2*OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE -1
gen y3=y2

local ivar1 "SELECTION EQUATION INDEPENDENT VARIABLES HERE, INCLUDING, IF APPPLICABLE, (a) THROUGH (c) DESCRIBED ON PAGE 1 OF THE CODEBOOK" 
local ivar2 "OUTCOME EQUATION INDEPENDENT VARIABLES FOR SIGNATORIES HERE"
local ivar3 "OUTCOME EQUATION INDEPENDENT VARIABLES FOR NON-SIGNATORIES HERE"


prob y1 `ivar1' 
local ll1=e(ll)
qui matrix i1 = e(b)
qui matrix coleq i1 = eq1:

prob OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE `ivar2' if y1==1
local ll2=e(ll)
qui matrix i2 = e(b)
qui matrix coleq i2 = eq2:
 
prob OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE `ivar3' if y1==0
local ll3=e(ll)
qui matrix i3 = e(b)
qui matrix coleq i3 = eq3:

heckprob OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE `ivar2', select (y1 = `ivar1') 
qui matrix i4 = e(b)
qui matrix rS=i4[1,"athrho:_cons"]
qui matrix coleq rS= eq4:

heckprob OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE `ivar3', select (y1n = `ivar1')
qui matrix i5 = e(b)
qui matrix rN=-i5[1,"athrho:_cons"]
qui matrix coleq rN= eq5:


qui matrix initvec = i1,i2,i3,rN

ml model lf biselect (y1 = `ivar1') (y2 = `ivar2') (y3 = `ivar3') ()
ml init initvec, skip
ml search
ml maximize, difficult

est store est3
*OBTAIN P-VALUE ASSOCIATED WITH RHO-S:
lrtest est1 est3

*End estimator 3

*---------------------------------------------------------------------------------------------------------------------------
*ESTIMATOR 4: this estimator will allow you to test the null hypothesis that rho-n is statistically insignificant. The 
*p-value associated with the chi-square value that you get at the end of the output is the p-value associated with the 
*variable rho-n. Be sure to run the entire file.
*Any section where you need to add information (variables, etc.) appears in CAPS below. Please refer to the codebook 
*(also in the zip file) for explanation.

*Begin estimator 4
capture program drop biselect
program define biselect
version 7
         args lnf theta1 theta2 theta3 zrhoS 

	tempvar rhoN rhoS 
	qui gen double `rhoS' = (exp(2*`zrhoS')-1) / (exp(2*`zrhoS')+1)

      quietly replace `lnf' = ln(($ML_y1==1)*binorm(`theta1',$ML_y2*`theta2', $ML_y2*`rhoS')+($ML_y1==0)*binorm(-`theta1',$ML_y3*`theta3', -$ML_y3*0))
end

set matsize 150
capture drop y1
capture drop y2
capture drop y3
capture drop y1n

gen y1=SELECTION DEPENDENT VARIABLE NAME HERE
gen y1n=-y1
gen y2=2*OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE -1
gen y3=y2

local ivar1 "SELECTION EQUATION INDEPENDENT VARIABLES HERE -- INCLUDING, IF APPROPRIATE, THE VARIABLES DESCRIBED IN (a) THROUGH (c) OF PAGE 1 OF THE CODEBOOK"
local ivar2 "OUTCOME EQUATION INDEPENDENT VARIABLES FOR SIGNATORIES HERE"
local ivar3 "OUTCOME EQUATION INDEPENDENT VARIABLES FOR NON-SIGNATORIES HERE"


prob y1 `ivar1'
local ll1=e(ll)
qui matrix i1 = e(b)
qui matrix coleq i1 = eq1:

prob OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE `ivar2' if y1==1
local ll2=e(ll)
qui matrix i2 = e(b)
qui matrix coleq i2 = eq2:
 
prob OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE `ivar3' if y1==0
local ll3=e(ll)
qui matrix i3 = e(b)
qui matrix coleq i3 = eq3:

heckprob OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE `ivar2', select (y1 = `ivar1') 
qui matrix i4 = e(b)
qui matrix rS=i4[1,"athrho:_cons"]
qui matrix coleq rS= eq4:

heckprob OUTCOME EQUATION DEPENDENT VARIABLE NAME HERE `ivar3', select (y1n = `ivar1')
qui matrix i5 = e(b)
qui matrix rN=-i5[1,"athrho:_cons"]
qui matrix coleq rN= eq5:


qui matrix initvec = i1,i2,i3,rS

ml model lf biselect (y1 = `ivar1') (y2 = `ivar2') (y3 = `ivar3') ()
ml init initvec, skip
ml search
ml maximize, difficult

est store est4
*OBTAIN P-VALUE ASSOCIATED WITH RHO-N
lrtest est1 est4

*End estimator 4
